Source Adapters
===============

.. automodule:: ceds_jsonld.adapters
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.base
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.csv_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.excel_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.dict_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.ndjson_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.api_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.database_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.google_sheets_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.snowflake_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.bigquery_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.databricks_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.canvas_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.oneroster_adapter
   :members:
   :show-inheritance:

.. automodule:: ceds_jsonld.adapters.sis_factories
   :members:
   :show-inheritance:
